@@ -103,6 +103,30 @@ on_album_artist_focus_out_event        (GtkWidget       *widget,
     return FALSE;
 }
 
+gboolean
+on_year_focus_out_event        (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data)
+{
+    const gchar * ctext = gtk_entry_get_text(GTK_ENTRY(widget));
+    gchar * text = malloc(5);
+    if (text == NULL)
+        fatalError("malloc(5) failed. Out of memory.");
+    strncpy(text, ctext, 5);
+    text[4] = '\0';
+    
+    if((text[0] != '1' && text[0] != '2') || text[1] < '0' || text[1] > '9' ||
+        text[2] < '0' || text[2] > '9' || text[3] < '0' || text[3] > '9')
+    {
+        sprintf(text, "1900");
+    }
+    
+    gtk_entry_set_text(GTK_ENTRY(widget), text);
+    
+    free(text);
+    return FALSE;
+}
+
 gboolean
 on_album_title_focus_out_event         (GtkWidget       *widget,
                                         GdkEventFocus   *event,
