@@ -168,7 +168,7 @@ create_main (void)
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 3, 0);
 
-    genre_label	= gtk_label_new (_("Genre:"));								// lnr
+    genre_label	= gtk_label_new (_("Genre / Year:"));								// lnr
     gtk_misc_set_alignment (GTK_MISC ( genre_label ), 0, 0);
     gtk_widget_show (genre_label);
     gtk_table_attach (GTK_TABLE (table2), genre_label, 0, 1, 3, 4,
@@ -176,8 +176,14 @@ create_main (void)
                       (GtkAttachOptions) (0), 3, 0);
 
     single_genre = gtk_check_button_new_with_mnemonic(_("Single Genre"));	// lnr
-    gtk_widget_show( single_genre );
-    gtk_table_attach( GTK_TABLE( table2 ), single_genre, 2, 3, 3, 4,
+    //~ gtk_widget_show( single_genre );
+    //~ gtk_table_attach( GTK_TABLE( table2 ), single_genre, 2, 3, 3, 4,
+                      //~ (GtkAttachOptions) ( GTK_FILL ),
+                      //~ (GtkAttachOptions) (0), 3, 0);
+                      
+    GtkWidget* album_year = gtk_entry_new();
+    gtk_widget_show(album_year);
+    gtk_table_attach( GTK_TABLE( table2 ), album_year, 2, 3, 3, 4,
                       (GtkAttachOptions) ( GTK_FILL ),
                       (GtkAttachOptions) (0), 3, 0);
 
@@ -266,7 +272,10 @@ create_main (void)
     g_signal_connect ((gpointer) single_genre, "toggled",
                                         G_CALLBACK (on_single_genre_toggled),
                                         NULL);
-
+    g_signal_connect ((gpointer) album_year, "focus_out_event",
+                                        G_CALLBACK (on_year_focus_out_event),
+                                        NULL);
+    
     /* KEYBOARD accelerators */
     GtkAccelGroup* accelGroup;
     guint accelKey;
@@ -318,6 +327,7 @@ create_main (void)
     GLADE_HOOKUP_OBJECT (main_win, album_genre, "album_genre");			// lnr
     GLADE_HOOKUP_OBJECT (main_win, genre_label, "genre_label" );		// lnr
     GLADE_HOOKUP_OBJECT (main_win, single_genre, "single_genre" );		// lnr
+    GLADE_HOOKUP_OBJECT (main_win, album_year, "album_year");
     
     return main_win;
 }
@@ -967,7 +977,7 @@ create_prefs (void)
     GLADE_HOOKUP_OBJECT (prefs, cddbServerName, "cddb_server_name");
     
     tooltips = gtk_tooltips_new ();
-    gtk_tooltips_set_tip (tooltips, cddbServerName, _("The CDDB server to get disc info from (default is freedb.org)"), NULL);
+    gtk_tooltips_set_tip (tooltips, cddbServerName, _("The CDDB server to get disc info from (default is freedb.freedb.org)"), NULL);
     
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_widget_show (hbox);
@@ -983,7 +993,7 @@ create_prefs (void)
     GLADE_HOOKUP_OBJECT (prefs, cddbPortNum, "cddb_port_number");
     
     tooltips = gtk_tooltips_new ();
-    gtk_tooltips_set_tip (tooltips, cddbPortNum, _("The CDDB server port (default is 888)"), NULL);
+    gtk_tooltips_set_tip (tooltips, cddbPortNum, _("The CDDB server port (default is 8880)"), NULL);
     
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
@@ -1199,6 +1209,7 @@ void disable_all_main_widgets(void)
     gtk_widget_set_sensitive(lookup_widget(win_main, "album_genre"), FALSE);	// lnr
     gtk_widget_set_sensitive(lookup_widget(win_main, "genre_label"), FALSE);	// lnr
     gtk_widget_set_sensitive(lookup_widget(win_main, "single_genre"), FALSE);	// lnr
+    gtk_widget_set_sensitive(lookup_widget(win_main, "album_year"), FALSE);
 }
 
 void enable_all_main_widgets(void)
@@ -1217,6 +1228,7 @@ void enable_all_main_widgets(void)
     gtk_widget_set_sensitive(lookup_widget(win_main, "album_genre"), TRUE);		// lnr
     gtk_widget_set_sensitive(lookup_widget(win_main, "genre_label"), TRUE);		// lnr
     gtk_widget_set_sensitive(lookup_widget(win_main, "single_genre"), TRUE);	// lnr
+    gtk_widget_set_sensitive(lookup_widget(win_main, "album_year"), TRUE);
 }
 
 void disable_mp3_widgets(void)
@@ -1323,7 +1335,7 @@ void enable_musepack_widgets(void)
 
 #if GTK_MINOR_VERSION >= 6
 static const char* 
-GBLprogramName = "Asunder 2.0";
+GBLprogramName = "Asunder 2.1";
 
 static const char* 
 GBLauthors[2] = {
@@ -1418,6 +1430,10 @@ GBLtranslators =
 "http://wiki.arabeyes.org/Translation_requests\n"
 "- ar (Arabic) translation of Asunder version 1.9\n"
 "\n"
+"Muhammad Ali Makki\n"
+"http://makki.urducoder.com/\n"
+"- ar (Arabic) translation of Asunder version 2.0\n"
+"\n"
 "Ihar Hrachyshka\n"
 "- be (Belarusian) translation of Asunder versions 1.0.2 - 1.5\n"
 "\n"
@@ -1436,6 +1452,9 @@ GBLtranslators =
 "Rene Schmidt\n"
 "- de (German) translation of Asunder versions 0.8 - 1.5\n"
 "\n"
+"Christian Faulhammer\n"
+"- de (German) translation of Asunder version 2.0\n"
+"\n"
 "Mike Kranidis\n"
 "- el (Greek) translation of Asunder versions 0.8 - 1.0, 1.9\n"
 "\n"
@@ -1448,6 +1467,9 @@ GBLtranslators =
 "Marco Antonio\n"
 "- es (Spanish) translation of Asunder version 1.9.3\n"
 "\n"
+"Guillermo Gras\n"
+"- eu (Basque) translation of Asunder version 2.0\n"
+"\n"
 "Eero Salokannel\n"
 "- fi (Finnish) translation of Asunder versions 0.8 - 1.5\n"
 "\n"
@@ -1512,7 +1534,7 @@ GBLtranslators =
 "- ru (Russian) translation of Asunder version 1.9.2\n"
 "\n"
 "Alexey Sivakov\n"
-"- ru (Russian) translation of Asunder versions 0.8 - 1.0, 1.9\n"
+"- ru (Russian) translation of Asunder versions 0.8 - 1.0, 1.9, 2.0\n"
 "\n"
 "Evgenii Terechkov\n"
 "- ru (Russian) translation of Asunder versions 1.0.2 - 1.5\n"
@@ -1534,10 +1556,14 @@ GBLtranslators =
 "\n"
 "Daniel Nylander\n"
 "- sv (Swedish) translation of Asunder versions 0.8 - 1.9\n"
-"\n"     
+"\n"
 "Savas Sen\n"
 "- tr (Turkish) translation of Asunder version 1.9\n"
 "\n"
+"Muhammad Ali Makki\n"
+"http://makki.urducoder.com/\n"
+"- ur_PK (Urdu/Pakistan) translation of Asunder version 2.0\n"
+"\n"
 "Cheng-Wei Chien\n"
 "- zh_TW (Chineese/Taiwan) translation of Asunder versions 0.8 - 1.9\n"
 "\n";
